#
# Copyright (C) 2025 Indiscale GmbH <info@indiscale.com>
# Copyright (C) 2025 Florian Spreckelsen <f.spreckelsen@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
"""This module serves a function that generates a human-readable
container name or label.

"""

import linkahead as db

from .utils import get_entity_name


def get_record_string(rec: db.Record) -> str:

    if rec.get_property(get_entity_name("abbreviation_prop")) is not None and rec.get_property(get_entity_name("abbreviation_prop")).value:
        return rec.get_property(get_entity_name("abbreviation_prop")).value

    if rec.name:
        return rec.name

    return ""


def get_container_name_prefix(responsible_id: int, container_type_id: int) -> str:
    """Generate a container name prefix from the container type and
    the responsible entity.

    Parameters
    ----------
    responsible_id : int
        LinkAhead id of the responsible entity (person, research
        institution, ...)
    container_type_id: int
        LinkAhead id of the ContainerType Record corresponding to the
        type of the given container.

    Returns
    -------
    container_name_prefix : str
        Name in the format `<responsible>_<container_type_name>`

    """
    resp = db.cached.cached_get_entity_by(eid=responsible_id)
    ct = db.cached.cached_get_entity_by(eid=container_type_id)

    resp_str = get_record_string(resp)
    ct_str = get_record_string(ct)

    if resp_str:
        return f"{resp_str}_{ct_str}"

    return ct_str
